.. image:: https://unipy.readthedocs.io/en/latest/_images/logo_white_background.svg
    :width: 400px
    :alt: unipy logo
    :align: center


|Travis|_  |AppVeyor|_  |Coveralls|_  |Readthedocs|_   
|PyPi|_  |Python35|_  |Python36|_ |DOI|_


.. |Travis| image:: https://travis-ci.org/pydemia/unipy.svg?branch=master
.. _Travis: https://travis-ci.org/pydemia/unipy

.. |AppVeyor| image:: https://ci.appveyor.com/api/projects/status/github/pydemia/unipy?branch=master&svg=true
.. _AppVeyor: https://ci.appveyor.com/project/pydemia/unipy/history

.. |Coveralls| image:: https://coveralls.io/repos/github/pydemia/unipy/badge.svg?branch=master&service=github
.. _Coveralls: https://coveralls.io/github/pydemia/unipy

.. |Readthedocs| image:: https://readthedocs.org/projects/unipy/badge/?version=latest
.. _Readthedocs: http://unipy.readthedocs.io/en/latest/?badge=latest

.. |PyPi| image:: https://badge.fury.io/py/unipy.svg
.. _PyPi: https://badge.fury.io/py/unipy.svg

.. |Python35| image:: https://img.shields.io/badge/python-3.5-blue.svg 
.. _Python35: https://badge.fury.io/py/unipy.svg 

.. |Python36| image:: https://img.shields.io/badge/python-3.6-blue.svg 
.. _Python36: https://badge.fury.io/py/unipy.svg 

.. |DOI| image:: https://zenodo.org/badge/21369/pydemia/unipy.svg
.. _DOI: https://zenodo.org/badge/latestdoi/21369/pydemia/unipy


What's for?
===========

`unipy` is a toolkit for data scientists.
This offers a number of scientific, statistical objects.
This also contains many pythonic objects like 
generators, decorators and function wrappers, etc.

Some famous datasets embedded will make you easy to test.


Installation
============

::

    pip install unipy



Usage
=====

::

    import unipy as up
    import unipy.dataset.api as dm



